@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+import logging
 from Products.Archetypes.public import process_types, listTypes
 from Products.CMFCore import utils
 from auslfe.formonline.pfgadapter.config import PROJECTNAME, ADD_CONTENT_PERMISSION
@@ -7,6 +8,8 @@ from auslfe.formonline.pfgadapter.config import PROJECTNAME, ADD_CONTENT_PERMISS
 from zope.i18nmessageid import MessageFactory
 formonline_pfgadapterMessageFactory = MessageFactory('auslfe.formonline.pfgadapter')
 
+logger = logging.getLogger("auslfe.formonline.pfgadapter")
+
 def initialize(context):
 
     import content
